# PointOfPresence

A PointOfPresence represents a physical location providing functionality to customers. Each point of presence resides in a fairly small geographical area. Some point of presences support more functionality than others, which is reflected in their capabilities. A point of presence's name is globally unique, and will never change. All point of presences are tagged with their name. 

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**spec** | [**PointOfPresenceSpec**](PointOfPresenceSpec.md) |  | 
**metadata** | [**MetadataWithId**](MetadataWithId.md) |  | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


